@@ -424,7 +424,7 @@ class BaseExperiment:
             if self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
                     batch_size=batch_size, 
-                    X=self.X.reshape(self.X.shape[0],-1), 
+                    X=self.X, 
                     y=self.y,
                     X_val=self.X_val,
                     y_val=self.y_val,
@@ -437,7 +437,7 @@ class BaseExperiment:
             elif self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
                     batch_size=batch_size, 
-                    X=self.X.reshape(self.X.shape[0],-1), 
+                    X=self.X, 
                     y=self.y,
                     X_val=self.X_val.reshape((self.X_val.shape[0], -1)),
                     y_val=self.y_val,
@@ -451,7 +451,7 @@ class BaseExperiment:
             elif self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
                 data_module = initialize_datamodule(
                     batch_size=batch_size, 
-                    X=self.X.reshape(self.X.shape[0],-1), 
+                    X=self.X, 
                     y=self.y,
                     X_val=self.X_val,
                     y_val=self.y_val,
@@ -462,10 +462,10 @@ class BaseExperiment:
                     stratify=self.stratify
                 )
 
-            elif self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
+            elif self.X_val is not None and self.y_val is not None and self.X_test is not None and self.y_test is not None:
                 data_module = initialize_datamodule(
                     batch_size=batch_size, 
-                    X=self.X.reshape(self.X.shape[0],-1), 
+                    X=self.X, 
                     y=self.y,
                     X_val=self.X_val,
                     y_val=self.y_val,
@@ -495,7 +495,7 @@ class BaseExperiment:
                     X_train, X_val, y_train, y_val = train_test_split(self.X, self.y, test_size=self.test_size)
                 else:
                     X_train, X_val, y_train, y_val = train_test_split(self.X, self.y, test_size=self.test_size, stratify=self.y)
-                data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
+                data_module = (X_train, X_val, y_train, y_val, self.X_test, self.y_test)
                 self.X_train, self.X_val = X_train, X_val
                 self.y_train, self.y_val = y_train, y_val
             else:
@@ -626,7 +626,7 @@ class BaseExperiment:
             y_test_predict_proba = y_test_predict_proba[:,1]
 
         if self.n_classes:
-            train_auc, val_auc, test_auc = math.nan
+            train_auc, val_auc, test_auc = math.nan, math.nan, math.nan
             
             if self.n_classes == 2:
                 train_auc = roc_auc_score(y_true=self.y_train, y_score=y_train_predict_proba)
@@ -662,6 +662,7 @@ class BaseExperiment:
         **trainer_config : Optional[Dict[str, Any]]
     )->"pl.LightningModule":  
         self.trainer = self.set_trainer(**trainer_config)
+        
         self.trainer.fit(self.model, self.data_module)
 
         if self.stack_models:    
@@ -768,10 +769,8 @@ class BaseExperiment:
         else:
             tensorboard_logdir = self.logger.experiment.get_logdir()
 
-        if model.__class__ in self.saved_model_types:
-            self.saved_model_types.update({model.__class__: self.saved_model_types[model.__class__] + 1})
-        else:
-            self.saved_model_types.update({model.__class__: 1})
+        self.saved_model_types.update({model.__class__.__name__: model.__class__})
+        
         
         self.n_ckpts += 1 
         self.log_metrics_to_json(model, tensorboard_logdir, jsonlog_path, val_metrics)
@@ -967,10 +966,11 @@ class BaseExperiment:
                     raise ValueError(f"Wrong file extension {ckpt_extension_type} for the checkpoint. It should be in {extension_candidates}")
                 if ckpt_extension_type == "sav":
                     best_ckpt = pickle.load(open(ckpt_dir, 'rb'))
-                elif BaseNet in inspect.getmro(eval(model_type)) or ConvNet in inspect.getmro(eval(model_type)):
-                    best_ckpt = eval(model_type).load_from_checkpoint(dims=self.dims, n_classes=self.n_classes, checkpoint_path=ckpt_dir)
-                elif pl.LightningModule in inspect.getmro(model_type):
-                    best_ckpt = eval(model_type).load_from_checkpoint(checkpoint_path=ckpt_dir)
+                elif pl.LightningModule in inspect.getmro(self.saved_model_types[model_type]):
+                    if BaseNet in inspect.getmro(self.saved_model_types[model_type]) or ConvNet in inspect.getmro(self.saved_model_types[model_type]):
+                        best_ckpt = self.saved_model_types[model_type].load_from_checkpoint(dims=self.dims, n_classes=self.n_classes, checkpoint_path=ckpt_dir)
+                    else:    
+                        best_ckpt = self.saved_model_types[model_type].load_from_checkpoint(checkpoint_path=ckpt_dir)
                 else:
                     raise AssertionError
                 return best_ckpt, info
